@@ -70,12 +70,14 @@ freepops.MODULES_MAP["yahoo.it"]       	= {name="yahoo.lua"}
 freepops.MODULES_MAP["yahoo.ca"] 	= {name="yahoo.lua"}
 freepops.MODULES_MAP["yahoo.co.in"] 	= {name="yahoo.lua"}
 freepops.MODULES_MAP["yahoo.co.id"] 	= {name="yahoo.lua"}
+freepops.MODULES_MAP["yahoo.co.nz"] 	= {name="yahoo.lua"}
 freepops.MODULES_MAP["yahoo.com.tw"] 	= {name="yahoo.lua"}
 freepops.MODULES_MAP["yahoo.co.uk"] 	= {name="yahoo.lua"}
 freepops.MODULES_MAP["yahoo.com.cn"] 	= {name="yahoo.lua"}
 freepops.MODULES_MAP["yahoo.com.br"] 	= {name="yahoo.lua"}
 freepops.MODULES_MAP["yahoo.com.hk"] 	= {name="yahoo.lua"}
 freepops.MODULES_MAP["yahoo.com.au"] 	= {name="yahoo.lua"}
+freepops.MODULES_MAP["yahoo.com.my"] 	= {name="yahoo.lua"}
 freepops.MODULES_MAP["yahoo.es"] 	= {name="yahoo.lua"}
 freepops.MODULES_MAP["yahoo.de"]        = {name="yahoo.lua"} 
 freepops.MODULES_MAP["yahoo.dk"]        = {name="yahoo.lua"} 
@@ -467,6 +469,7 @@ freepops.MODULES_MAP["italymail.com" ]		= {name="mailcom.lua"}
 freepops.MODULES_MAP["computer4u.com"]		= {name="mailcom.lua"}
 freepops.MODULES_MAP["mexico.com"]		= {name="mailcom.lua"}
 freepops.MODULES_MAP["india.com"]		= {name="mailcom.lua"}
+freepops.MODULES_MAP["royal.net"]		= {name="mailcom.lua"}
 
 -- mail2world
 freepops.MODULES_MAP["mail2.*%.com" ]		= {name="mail2world.lua", 
