@@ -1,4 +1,4 @@
-#!/bin/bash
+#!/bin/sh
 # vim:ts=4:
 
 usage() {
@@ -12,9 +12,10 @@ Available options:
 	linux-gnutls	to compile on a linux host and install in /usr/local
 			using gnutls and not openssl
 	linux-slack	to compile on a linux slack box (installs in /usr)
-	osx-i386	to compile on a darwin host (Xcode 2.4.1 + custom expat)
-	osx-ppc		to compile on a darwin host (Xcode 2.4.1 + custom expat)
-	osx-static	to compile on a darwin host with some static libs
+	osx			to compile on a darwin host (sdk10.4u + custom expat:
+				you can export the EXTRALIB_PREFIX variable pointing
+				to the installation root of your expat installation)
+	osx-static	to compile on a darwin host (old osx versions)
 	obsd		to compile on a openbsd host
 	fbsd 		to compile on a freebsd host
 	solaris 	to compile on a solaris host
@@ -29,15 +30,12 @@ Flags (need $PKGCONFIG as provided in Debian):
 	-luaexpat       use system lua5.1-expat
 	-luacurl        use system lua5.1-curl 
 	-luafilesystem  use system lua5.1-filesystem 
+	-luasocket  	use system lua5.1-socket 
 	-lua            use system lua5.1
 
 Flags (need fltk-config):
 	-fltk-ui        build the fltk updater user interface
 
-Flags:
-	-expat-lib-dir  looks for libexpat.a in this path (osx only), default
-	                is \$PWD/../lib/lib/
-
 EOT
 
 }
@@ -57,7 +55,7 @@ HRANLIB=${HRANLIB:-$RANLIB}
 EXEEXTENSION=${EXEEXTENSION:-""}
 STATICEXTENSION=${STATICEXTENSION:-.a}
 SHAREDEXTENSION=${SHAREDEXTENSION:-.so}
-CFLAGS=${CFLAGS:-"-O2 -g3 -Wall -Wextra -DHAVE_CONFIG_H -I$PWD"}
+CFLAGS="${CFLAGS:-"-O2 -g3 -Wall -Wextra"} -DHAVE_CONFIG_H -I$PWD"
 HCFLAGS=${HCFLAGS:-$CFLAGS}
 LDFLAGS=${LDFLAGS:-""}
 HLDFLAGS=${HLDFLAGS:-$LDFLAGS}
@@ -65,6 +63,7 @@ WINDRES=${WINDRES:-windres}
 DLLTOOL=${DLLTOOL:-dlltool}
 MAKE=${MAKE:-make}
 WHERE=${WHERE:-/usr/local/}
+LOCALEDIR=${LOCALEDIR:-/usr/local/share/locale/}
 TAR=${TAR:-tar}
 PATCH=${PATCH:-patch}
 SSL=${SSL:-openssl}
@@ -73,7 +72,7 @@ FLTKCFLAGS=${FLTKCFLAGS:-""}
 FLTKLDFLAGS=${FLTKLDFLAGS:-""}
 MACHOARCH=${MACHOARCH:-""}
 LUAFLAGS=${LUAFLAGS:-""}
-LIBEXPAT_STATIC_PATH=${LIBEXPAT_STATIC_PATH:-$PWD/../lib/lib/}
+OSX_SDK=${OSX_SDK:-""}
 }
 
 set_linux() {
@@ -95,42 +94,25 @@ set_linux_slack() {
 set_default
 CFLAGS="-O2 -g3 -march=i486 -Wall -DHAVE_CONFIG_H -I$PWD"
 WHERE=/usr/
+LOCALEDIR=/usr/share/locale/
 OS=Linux
 LUAFLAGS=" -DLUA_USE_LINUX "
 }
 
-set_osx_default() {
+set_osx() {
 set_default
 OS=Darwin
-CFLAGS="$CFLAGS -I/sw/include -DMACOSX"
-HCFLAGS="$HCFLAGS -I/sw/include -DMACOSX"
+OSX_SDK=/Developer/SDKs/MacOSX10.4u.sdk/
+EXTRALIB_PREFIX=${EXTRALIB_PREFIX:-/Users/gares/freepops/}
+OSXV=10.4
+MACHOARCH=" -arch i386 -arch ppc -isysroot $OSX_SDK -mmacosx-version-min=$OSXV"
+CFLAGS="$CFLAGS -I${EXTRALIB_PREFIX}include -DMACOSX"
+HCFLAGS="$HCFLAGS -I${EXTRALIB_PREFIX}include -DMACOSX"
 LUAFLAGS=" -DLUA_USE_MACOSX "
-}
-
-set_osx_i386(){
-set_osx_default
-MACHOARCH=" -arch i386 -isysroot /Developer/SDKs/MacOSX10.4u.sdk/ -mmacosx-version-min=10.4"
-LDFLAGS="$LDFLAGS -Wl,-syslibroot,/Developer/SDKs/MacOSX10.4u.sdk/ -mmacosx-version-min=10.4"
-EXEEXTENSION=.i386-10.4
-}
-set_osx_ppc64(){
-set_osx_default
-MACHOARCH=" -arch ppc64 -isysroot /Developer/SDKs/MacOSX10.4u.sdk/ -mmacosx-version-min=10.4"
-LDFLAGS="$LDFLAGS -Wl,-syslibroot,/Developer/SDKs/MacOSX10.4u.sdk/ -mmacosx-version-min=10.4"
-EXEEXTENSION=.ppc64-10.4
-}
-set_osx_x86_64(){
-set_osx_default
-MACHOARCH=" -arch x86_64 -isysroot /Developer/SDKs/MacOSX10.4u.sdk/ -mmacosx-version-min=10.4"
-LDFLAGS="$LDFLAGS -Wl,-syslibroot,/Developer/SDKs/MacOSX10.4u.sdk/ -mmacosx-version-min=10.4"
-EXEEXTENSION=.x86_64-10.4
-}
-
-set_osx_ppc(){
-set_osx_default
-MACHOARCH=" -arch ppc -isysroot /Developer/SDKs/MacOSX10.3.9.sdk/ -mmacosx-version-min=10.3"
-LDFLAGS="$LDFLAGS -Wl,-syslibroot,/Developer/SDKs/MacOSX10.3.9.sdk/ -mmacosx-version-min=10.3"
-EXEEXTENSION=.ppc-10.3
+LDFLAGS="$LDFLAGS -L${EXTRALIB_PREFIX}lib -Wl,-syslibroot,$OSX_SDK -mmacosx-version-min=$OSXV"
+EXEEXTENSION=".ppc-i386.$OSXV"
+FLTKLDFLAGS="-lfltk -framework Carbon -framework ApplicationServices"
+FLTKPOST="${EXTRALIB_PREFIX}bin/fltk-config --post"
 }
 
 set_osx_static() {
@@ -138,11 +120,11 @@ set_default
 OS=Darwin-static
 CFLAGS="$CFLAGS -I/sw/include -DMACOSX -DOSXSTC"
 HCFLAGS="$HCFLAGS -I/sw/include -DMACOSX -DOSXSTC"
-LDFLAGS="$LDFLAGS -L/sw/lib" 
+LDFLAGS="$LDFLAGS -L/sw/lib"
 HLDFLAGS="$HLDFLAGS -L/sw/lib"
 LUAFLAGS=" -DLUA_USE_MACOSX "
 if [ `uname -r` = '8.8.3' ]; then
-	MACHOARCH=" -arch i386 -arch ppc -mmacosx-version-min=10.3"
+        MACHOARCH=" -arch i386 -arch ppc -mmacosx-version-min=10.3"
 fi
 }
 
@@ -202,61 +184,27 @@ local firstpref
 local defpref
 set_default
 firstpref=/usr/bin/i586-mingw32msvc-
-defpref=/usr/local/cross-tools/i386-mingw32msvc/bin/
-if test -x ${firstpref}gcc; then
-	CC=${firstpref}gcc
-	CXX=${firstpref}g++
-	DLLPATH=/usr/i586-mingw32msvc/bin/
-	INCLUDEPATH=/usr/i586-mingw32msvc/include/
-	LDFLAGSDL=
-	CURLNAME=curl
-else
-	CC=${defpref}gcc
-	CXX=${defpref}g++
-	DLLPATH=/usr/local/cross-tools/i386-mingw32msvc/bin/
-	INCLUDEPATH=/usr/local/cross-tools/i386-mingw32msvc/include/
-	LDFLAGSDL=-ldl
-	CURLNAME=curl
-fi
+CC=${firstpref}gcc
+CXX=${firstpref}g++
+DLLPATH=/usr/i586-mingw32msvc/bin/
+INCLUDEPATH=/usr/i586-mingw32msvc/include/
+LDFLAGSDL=
+CURLNAME=curl
 HCC=gcc
-if test -x ${firstpref}ld; then
-	LD=${firstpref}ld
-else
-	LD=${defpref}ld
-fi
+LD=${firstpref}ld
 HLD=ld
-if test -x ${firstpref}ar; then
-	AR=${firstpref}ar
-else
-	AR=${defpref}ar
-fi
+AR=${firstpref}ar
 HAR=ar
-if test -x ${firstpref}strip; then
-	STRIP=${firstpref}strip
-else
-	STRIP=${defpref}strip
-fi
+STRIP=${firstpref}strip
 HSTRIP=strip
-if test -x ${firstpref}ranlib; then
-	RANLIB=${firstpref}ranlib
-else
-	RANLIB=${defpref}ranlib
-fi
+RANLIB=${firstpref}ranlib
 HRANLIB=ranlib
-if test -x ${firstpref}windres; then
-	WINDRES=${firstpref}windres
-else
-	WINDRES=/usr/local/cross-tools/bin/i386-mingw32msvc-windres
-fi
+WINDRES=${firstpref}windres
 EXEEXTENSION=.exe
 SHAREDEXTENSION=.dll
 CFLAGS="$CFLAGS -DWIN32 -mwindows " # " -mms-bitfields"
 LDFLAGS="$LDFLAGS -lmsvcrt -lmingw32  -lwsock32 -mwindows " # "-mms-bitfields"
-if test -x ${firstpref}dlltool; then
-	DLLTOOL=${firstpref}dlltool
-else
-	DLLTOOL=${defpref}dlltool
-fi
+DLLTOOL=${firstpref}dlltool
 OS=Windows
 LUAFLAGS=" -DLUA_WIN"
 }
@@ -279,6 +227,7 @@ LUAEXPAT=luaexpat
 LUACURL=luacurl
 LUALUA=lua
 LUAFILESYSTEM=luafilesystem
+LUASOCKET=luasocket
 
 PKGCONFIG=${PKGCONFIG:-pkg-config}
 
@@ -322,17 +271,8 @@ case $1 in
 	fbsd)
 		set_fbsd
 	;;
-	osx-i386)
-		set_osx_i386
-	;;
-	osx-ppc)
-		set_osx_ppc
-	;;
-	osx-x86_64)
-		set_osx_x86_64
-	;;
-	osx-ppc64)
-		set_osx_ppc64
+	osx)
+		set_osx
 	;;
 	osx-static)
 		set_osx_static
@@ -388,6 +328,13 @@ while [ ! -z "$1" ]; do
 			CFLAGS="$CFLAGS `$PKGCONFIG lua5.1-filesystem --cflags`"
 			LDFLAGS="$LDFLAGS `$PKGCONFIG lua5.1-filesystem --libs`"
 		;;
+		-luasocket)
+			LUASOCKET=
+			HCFLAGS="$HCFLAGS `$PKGCONFIG lua5.1-socket --cflags`"
+			HLDFLAGS="$HLDFLAGS `$PKGCONFIG lua5.1-socket --libs`"
+			CFLAGS="$CFLAGS `$PKGCONFIG lua5.1-socket --cflags`"
+			LDFLAGS="$LDFLAGS `$PKGCONFIG lua5.1-socket --libs`"
+		;;
 		-fltk-ui)
 			FLTKUI=1
 			if [ "$OS" != "Windows" ]; then
@@ -398,10 +345,6 @@ while [ ! -z "$1" ]; do
 				FLTKLDFLAGS=" -lfltk -lintl -lgdi32 -lwsock32 -lole32 -luuid -L ../../src/ -lfp"
 			fi
 		;;
-		-expat-lib-dir)
-			shift
-			LIBEXPAT_STATIC_PATH="$1"
-		;;
 		*)
 			usage
 			exit 1
@@ -439,6 +382,7 @@ CURLNAME=$CURLNAME
 OS=$OS
 MAKE=$MAKE
 WHERE=$WHERE
+LOCALEDIR=$LOCALEDIR
 TAR=$TAR
 PATCH=$PATCH
 SSL=$SSL
@@ -447,6 +391,7 @@ LUAEXPAT=$LUAEXPAT
 LUACURL=$LUACURL
 LUALUA=$LUALUA
 LUAFILESYSTEM=$LUAFILESYSTEM
+LUASOCKET=$LUASOCKET
 
 FLTKUI=$FLTKUI
 FLTKCFLAGS=$FLTKCFLAGS
@@ -454,7 +399,8 @@ FLTKLDFLAGS=$FLTKLDFLAGS
 
 MACHOARCH=$MACHOARCH
 LUAFLAGS=$LUAFLAGS
+OSX_SDK=$SDK
+FLTKPOST=$FLTKPOST
 
-LIBEXPAT_STATIC_PATH=$LIBEXPAT_STATIC_PATH
 EOT
 
