@@ -1,5 +1,5 @@
 /******************************************************************************
- * $Id: base64.c,v 1.3 2005/09/26 22:22:44 gareuselesinge Exp $
+ * $Id: base64.c,v 1.5 2007/06/22 15:10:38 gareuselesinge Exp $
  * This file is part of liberopops (http://liberopops.sf.net)                 *
  * This file is distributed under the terms of GNU GPL license.               *
  ******************************************************************************/
@@ -125,7 +125,7 @@ static unsigned int index_in_table(char c){
 
 char *base64dec(const char *input, size_t len){
 	char * rc = calloc(len * 3 / 4 + 4,sizeof(char));
-	int i,o=0;
+	size_t i,o=0;
 	MALLOC_CHECK(rc);
 
 	for(i=0; i+3<=len; ){
