@@ -1,5 +1,5 @@
 /******************************************************************************
- * $Id: getdate_lua.c,v 1.6 2007/01/13 22:36:23 gareuselesinge Exp $
+ * $Id: getdate_lua.c,v 1.7 2008/04/02 09:12:44 gareuselesinge Exp $
  * This file is part of FreePOPs (http://www.freepops.org)                    *
  * This file is distributed under the terms of GNU GPL license.               *
  ******************************************************************************/
@@ -31,14 +31,14 @@ lua_pushnumber(L,rc);
 return 1;
 }
 
-static const struct luaL_reg getdate_f [] = {
+static const struct luaL_Reg getdate_f [] = {
   {"toint",L_getdate},
   {NULL,NULL}
 };
 
 int luaopen_getdate(lua_State* L) {
 	
-	luaL_openlib(L,"getdate",getdate_f,0);
+	luaL_register(L,"getdate",getdate_f);
 
 	return 1;
 }
