@@ -1,5 +1,5 @@
 /******************************************************************************
- * $Id: log.c,v 1.13 2007/01/13 22:36:23 gareuselesinge Exp $
+ * $Id: log.c,v 1.14 2008/06/11 19:22:35 gareuselesinge Exp $
  * This file is part of liberopops (http://liberopops.sf.net)                 *
  * This file is distributed under the terms of GNU GPL license.               *
  ******************************************************************************/
@@ -344,7 +344,7 @@ int logit(char* zone, char* preamble, char*filename,int line,char *str, ...)
 	
 		// put an endline if the string was truncated
 		if (rc >= MAX_LOG_STRING-1 && strtmp[MAX_LOG_STRING-2] != '\n')
-		{	printf("XXX\n");	strtmp[MAX_LOG_STRING-2] = '\n';}
+			strtmp[MAX_LOG_STRING-2] = '\n';
 
 		fprintf(fd, "%s", strtmp);
 		fflush(fd);
