@@ -1,5 +1,5 @@
 /******************************************************************************
- * $Id: luay.c,v 1.8 2005/06/11 12:01:47 gareuselesinge Exp $
+ * $Id: luay.c,v 1.13 2007/03/20 11:29:18 gareuselesinge Exp $
  * This file is part of FreePOPs (http://www.freepops.org)                    *
  * This file is distributed under the terms of GNU GPL license.               *
  ******************************************************************************/
@@ -68,11 +68,14 @@ for(i=lua_gettop(s) ; i > 0 ; i-- )
 		break;
 		case LUA_TBOOLEAN:
 			fprintf(stderr," %s\n",
-				lua_toboolean(s,i)==0?"true":"false");
+				lua_toboolean(s,i)==0?"false":"true");
 		break;
 		case LUA_TNIL:
 			fprintf(stderr," nil\n");
 		break;
+		case LUA_TTABLE:
+			fprintf(stderr," array part is %lu\n",lua_objlen(s,i));
+		break;
 		default:
 			fprintf(stderr," ??\n");
 		break;
@@ -126,6 +129,12 @@ switch(x)\
 		lua_pushlightuserdata(s,p);\
 		}\
 	break;\
+	case 'v':\
+		{\
+		int v = va_arg(vargs,int);\
+		lua_pushvalue(s,v);\
+		}\
+	break;\
 	default:\
 		goto error;\
 	break;\
@@ -187,11 +196,13 @@ switch(x)\
 		*p = lua_touserdata(s,base+1);\
 		}\
 	break;\
+	case 'v': break;\
 	default:\
 		goto error;\
 	break;\
 	}\
-lua_remove(s,base+1);\
+if (x != 'v') \
+	lua_remove(s,base+1);\
 }\
 
 #define PREAMBLE \
@@ -277,9 +288,7 @@ if(rc != 0)
 // pop returns
 if(nret > 0)
 	for(i++;args[i] != '\0';i++)
-		{
 		luay_poparg(s,args[i],vargs);
-		}
 
 // empty the stack (needed for the c function)
 lua_remove(s,base);
@@ -313,7 +322,7 @@ for(i = 0 ; i<len ; i++)
 	}
 
 // count return values
-nret = strlen(&args[i]) -1;
+nret = strlen(args) -1; // -1 is for '|'
 
 //call the function
 #ifdef PRINT_FUNCTIONS
