@@ -1,5 +1,5 @@
 /******************************************************************************
- * $Id: popserver.c,v 1.16 2007/01/13 22:36:24 gareuselesinge Exp $
+ * $Id: popserver.c,v 1.21 2007/10/27 13:21:09 gareuselesinge Exp $
  * This file is part of liberopops (http://liberopops.sf.net)                 *
  * This file is distributed under the terms of GNU GPL license.               *
  ******************************************************************************/
@@ -33,6 +33,7 @@
 #include "popserver.h"
 #include "popstate.h"
 #include "threads.h"
+#include "stats.h"
 
 #ifdef HAVE_CONFIG_H
 	#include "config.h"
@@ -214,15 +215,15 @@ char * POPSERVER_ERR_MSG[]={
 	"UNKNOWN ERROR, PLEASE FIX"};
 
 enum states_e POPSERVER_ERR_STA[]={
-	POPSTATE_LAST,
-	POPSTATE_ERR,
-	POPSTATE_ERR,
-	POPSTATE_ERR,
-	POPSTATE_LAST,
-	POPSTATE_ERR,
-	POPSTATE_ERR,
-	POPSTATE_ERR,
-	POPSTATE_ERR};
+	POPSTATE_LAST, // <-- POPSERVER_ERR_SYNTAX
+	POPSTATE_ERR,  // <-- POPSERVER_ERR_NETWORK
+	POPSTATE_ERR,  // <-- POPSERVER_ERR_AUTH
+	POPSTATE_ERR,  // <-- POPSERVER_ERR_INTERNAL
+	POPSTATE_LAST, // <-- POPSERVER_ERR_NOMSG
+	POPSTATE_ERR,  // <-- POPSERVER_ERR_LOCKED
+	POPSTATE_ERR,  // <-- POPSERVER_ERR_EOF
+	POPSTATE_ERR,  // <-- POPSERVER_ERR_TOOFAST
+	POPSTATE_ERR}; // <-- POPSERVER_ERR_UNKNOWN
 
 int POPSERVER_ERR_NUM=POPSERVER_ERR_UNKNOWN;
 
@@ -237,7 +238,7 @@ HIDDEN enum states_e send_result_simple(struct sock_state_t *s,int rc,
 {
 char ans[RFC_1939_MAXLINELEN];
 	
-if(rc != 0)
+if(rc != POPSERVER_ERR_OK)
 	{
 	P("%s %s",RFC_1939_ERR,err_comment[MIN(rc-1,numerr-1)]);
 	sock_send(s,ans);
@@ -266,7 +267,7 @@ HIDDEN enum states_e send_result_multiline(struct sock_state_t *s,int rc,
 {
 char ans[RFC_1939_MAXLINELEN];
 	
-if(rc != 0)
+if(rc != POPSERVER_ERR_OK)
 	{
 	P("%s %s",RFC_1939_ERR,err_comment[MIN(rc-1,numerr-1)]);
 	sock_send(s,ans);
@@ -292,7 +293,7 @@ else
  * marshaller for retr
  */
 int marshaller_retr(struct popstate_t*p,struct popserver_functions_t *f,
-	struct sock_state_t *s, int msg,int lines)
+	struct sock_state_t *s, int msg,int lines __attribute__((unused)))
 {
 return f->retr(p,msg,s);
 }
@@ -320,7 +321,7 @@ HIDDEN enum states_e send_result_callback(
 		int (*marshaller)
 			(struct popstate_t*p,struct popserver_functions_t *f,
 			struct sock_state_t *s, int msg,int lines),
-		char* err_comment[],
+		char* err_comment[] __attribute__ ((unused)),
 		enum states_e err_next[],
 		int numerr,
 		enum states_e suc_next)
@@ -428,8 +429,9 @@ enum states_e next;
 int rc=0;
 
 sock_receive_with_timeout(s,ask,RFC_1939_MAXLINELEN,POPSERVER_NOOP_TIMEOUT);
-if(sock_error_occurred(s))
+if(sock_error_occurred(s)) {
 	return POPSTATE_AUTH;
+}
 
 if(matches(RFC_1939_QUIT,ask)) /*** QUIT *********************/
 	{
@@ -500,6 +502,9 @@ else
 			POPSTATE_ERR);	
 		}
 	}
+
+STATS_LOG_IF(next == POPSTATE_ERR, session_err,rc);
+
 return next;
 }
 
@@ -525,8 +530,9 @@ enum states_e next=POPSTATE_ERR;
 int rc=0;
 
 sock_receive_with_timeout(s,ask,RFC_1939_MAXLINELEN,POPSERVER_NOOP_TIMEOUT);
-if(sock_error_occurred(s))
+if(sock_error_occurred(s)) {
 	return POPSTATE_TRANS;
+}
 
 if(matches(RFC_1939_STAT,ask)) /*** STAT *********************/
 	{
@@ -734,6 +740,9 @@ else
 			POPSTATE_ERR);
 		}
 	}
+
+STATS_LOG_IF(next == POPSTATE_ERR, session_err,rc);
+
 return next;
 }
 
@@ -765,6 +774,7 @@ while(!stop)
 			f->quit(p);	
 		sock_disconnect(s);
 		thread_die(pthread_self());
+		STATS_LOG(session_err,POPSERVER_ERR_NETWORK);
 		break;
 		}
 
@@ -791,6 +801,7 @@ while(!stop)
 			sock_disconnect(s);
 			thread_die(pthread_self());
 			stop=1;
+			STATS_LOG(session_ok);
 		break;
 
 		case POPSTATE_LAST:
@@ -843,6 +854,8 @@ while(1)
 	{
 	new=sock_listen(s);
 
+	STATS_LOG(connection_established);
+
 	thread_clean(); //clean dead threads
 	thread_get_free(&pth,&att); //get a free thread
 	
@@ -854,7 +867,6 @@ while(1)
 		continue;
 		}
 
-
 	p = new_popstate_t();
 
 	//create the data to pass to pop3 thread
@@ -873,6 +885,8 @@ while(1)
 		free(data);
 		ERROR_ABORT("pthread_create failed\n");
 		}
+	
+	STATS_LOG(session_created);
 
 	#ifdef WIN32
 	//FIXME
