@@ -3,7 +3,14 @@
 -- This module implements some looping primitives, some useful wrappers.
 -- should be used to make code shorter.
 
-module("support")
+MODULE_VERSION = "0.0.1"
+MODULE_NAME = "support"
+MODULE_REQUIRE_VERSION = "0.2.0"
+MODULE_LICENSE = "GNU/GPL"
+MODULE_URL = "http://www.freepops.org/download.php?module=support.lua"
+MODULE_HOMEPAGE = "http://www.freepops.org/"
+
+module("support",package.seeall)
 
 --============================================================================--
 -- This is part of FreePOPs (http://www.freepops.org) released under GNU/GPL  
@@ -128,7 +135,7 @@ function do_extract(t,field,exp)
 			return nil,"Unable to capture "..exp..
 				" the data was nil"
 		end
-		local _,_,r = string.find(s,exp)
+		local r = string.match(s,exp)
 		if not r then
 			print("Unable to capture "..exp..
 				" the data was " ..s)
