@@ -9,7 +9,7 @@
 
 -- Globals
 --
-PLUGIN_VERSION = "0.1.88a"
+PLUGIN_VERSION = "0.1.90"
 PLUGIN_NAME = "hotmail.com"
 PLUGIN_REQUIRE_VERSION = "0.2.0"
 PLUGIN_LICENSE = "GNU/GPL"
@@ -58,6 +58,12 @@ Parameter is used to override the domain in the email address.  This is used so
 need to add a mapping to config.lua for a hosted hotmail account. ]]
 		}	
 	},
+	{name = "keepmsgstatus", description = {
+		en = [[
+Parameter is used to maintain the status of the message in the state it was before being pulling.  If the value is 1, the behavior is turned on
+and will override the markunread flag.. ]]
+		}	
+	},
 }
 PLUGIN_DESCRIPTIONS = {
 	it=[[
@@ -100,7 +106,9 @@ local globals = {
   --
   strRetLoginBadLogin = "(memberservices)",
   strRetLoginSessionExpired = "(Sign in)",
-  strRetLoginSessionExpiredLive = '(HM%.FppError)',
+  strRetLoginSessionExpiredLiveLight = '(</li></ul><a class="ManageLink" href="ManageFoldersLight%.aspx)',
+  strRetLoginSessionErrorLive = '(HM%.FppError)',
+  strRetLoginSessionExpiredLive = '(new HM%.FppReturnPackage%(0,new HM',
   strRetStatBusy = "(form name=.hotmail.)",
   
   -- Regular expression to extract the mail server
@@ -118,6 +126,10 @@ local globals = {
   strLoginDoneReloadToHMHome3="location='([^']+)'",
 --  strLoginDoneReloadToHMHome3='location=.([^"%']+)',
   strLoginDoneReloadToHMHome4="img src='([^']+)'",
+
+  -- Paco
+  strLoginDoneReloadToHMHome5='img src="([^"]+)"',
+
   strLoginDoneReloadToReloadPage='window%.location=\'([^\']+)\'',
  
   -- Pattern to detect if we are using the live or classic version
@@ -174,7 +186,7 @@ local globals = {
   --
   strMsgListCntPattern = "<td width=100. align=center>([^<]+)</td><td align=right nowrap>",
   strMsgListCntPattern2 = "([%d]+) [MmNnBbVv][eai]",
-  strMsgListLiveLightCntPattern = '<div class="dItemListHeaderMsgInfo".->.-(%d+).-</div>',
+  strMsgListLiveLightCntPattern = '<div class=".-ItemListHeaderMsgInfo".->.-(%d+).-</div>',
 
   -- Used by Stat to pull out the message ID and the size
   --
@@ -186,6 +198,7 @@ local globals = {
   --
   strMsgListNextPagePattern = '(nextpg%.gif" border=0></a>)',
   strMsgListNextPagePatLiveLight = '<a href="([^"]+)"[^>]*><img src="[^_]*_nextpage.gif"',
+  strMsgListNextPagePatLiveLight2 = '<a href="([^"]+)"[^>]*><img src="[^"]+" class="i_nextpage"',
 
   -- Pattern used to detect a bad STAT page.
   --
@@ -215,17 +228,17 @@ local globals = {
   strCmdBrowserIgnoreLive = "http://%s/mail/mail.aspx?skipbrowsercheck=true",
   strCmdMsgList = "http://%s/cgi-bin/HoTMaiL?a=%s&curmbox=%s",
   strCmdMsgListNextPage = "&page=%d&wo=",
-  strCmdMsgListLiveLight = "http://%s/mail/InboxLight.aspx?FolderID=%s",
-  strCmdMsgListLive = "http://%s/mail/mail.fpp?cnmn=Microsoft.Msn.Hotmail.MailBox.GetFolderData&ptid=0&a=%s&au=%s", 
-  strCmdMsgListPostLiveOld = "cn=Microsoft.Msn.Hotmail.MailBox&mn=GetFolderData&d=%s,Date,%s,false,0,%s,0,,&MailToken=",
-  strCmdMsgListPostLive = 'cn=Microsoft.Msn.Hotmail.MailBox&mn=GetFolderData&d=%s,Date,%s,false,0,%s,0,"","",true,false&v=1&mt=%s',
+  strCmdMsgListLiveLight = "http://%s/mail/InboxLight.aspx?FolderID=%s&InboxSortBy=Date&",
+  strCmdMsgListLive = "http://%s/mail/mail.fpp?cnmn=Microsoft.Msn.Hotmail.Ui.Fpp.MailBox.GetFolderData&ptid=0&a=%s&au=%s", 
+  strCmdMsgListPostLiveOld = "cn=Microsoft.Msn.Hotmail.Ui.Fpp.MailBox&mn=GetFolderData&d=%s,Date,%s,false,0,%s,0,,&MailToken=",
+  strCmdMsgListPostLive = 'cn=Microsoft.Msn.Hotmail.Ui.Fpp.MailBox&mn=GetFolderData&d=%s,Date,%s,false,0,%s,0,"","",true,false&v=1&mt=%s',
 
   strCmdDelete = "http://%s/cgi-bin/HoTMaiL",
   strCmdDeletePost = "curmbox=%s&_HMaction=delete&wo=&SMMF=0", -- &<MSGID>=on
-  strCmdDeleteLive = "http://%s/mail/mail.fpp?cnmn=Microsoft.Msn.Hotmail.MailBox.MoveMessages&ptid=0&a=%s&au=%s", 
-  strCmdDeletePostLiveOld = 'cn=Microsoft.Msn.Hotmail.MailBox&mn=MoveMessages&d="%s","%s",[%s],[{"%%5C%%7C%%5C%%7C%%5C%%7C0%%5C%%7C%%5C%%7C%%5C%%7C00000000-0000-0000-0000-000000000001%%5C%%7C632901424233870000",{2,"00000000-0000-0000-0000-000000000000",0}}],null,null,0,false,Date&v=1',
-  -- strCmdDeletePostLive = 'cn=Microsoft.Msn.Hotmail.MailBox&mn=MoveMessages&d="%s","%s",[%s],[{"%%5C%%7C%%5C%%7C%%5C%%7C0%%5C%%7C%%5C%%7C%%5C%%7C%%5C%%7C00000000-0000-0000-0000-000000000001%%5C%%7C632750213035330000",null}],null,null,0,false,Date,false,true&v=1&mt=%s',
-  strCmdDeletePostLive = 'cn=Microsoft.Msn.Hotmail.MailBox&mn=MoveMessages&d="%s","%s",[%s],[{"0%%5C%%7C0%%5C%%7C8C9BDFF65883200%%5C%%7C00000000-0000-0000-0000-000000000001",null}],null,null,0,false,Date,false,true&v=1&mt=%s',
+  strCmdDeleteLive = "http://%s/mail/mail.fpp?cnmn=Microsoft.Msn.Hotmail.Ui.Fpp.MailBox.MoveMessages&ptid=0&a=%s&au=%s", 
+  strCmdDeletePostLiveOld = 'cn=Microsoft.Msn.Hotmail.Ui.Fpp.MailBox&mn=MoveMessages&d="%s","%s",[%s],[{"%%5C%%7C%%5C%%7C%%5C%%7C0%%5C%%7C%%5C%%7C%%5C%%7C00000000-0000-0000-0000-000000000001%%5C%%7C632901424233870000",{2,"00000000-0000-0000-0000-000000000000",0}}],null,null,0,false,Date&v=1',
+  -- strCmdDeletePostLive = 'cn=Microsoft.Msn.Hotmail.Ui.Fpp.MailBox&mn=MoveMessages&d="%s","%s",[%s],[{"%%5C%%7C%%5C%%7C%%5C%%7C0%%5C%%7C%%5C%%7C%%5C%%7C%%5C%%7C00000000-0000-0000-0000-000000000001%%5C%%7C632750213035330000",null}],null,null,0,false,Date,false,true&v=1&mt=%s',
+  strCmdDeletePostLive = 'cn=Microsoft.Msn.Hotmail.Ui.Fpp.MailBox&mn=MoveMessages&d="%s","%s",[%s],[{"0%%5C%%7C0%%5C%%7C8C9BDFF65883200%%5C%%7C00000000-0000-0000-0000-000000000001",null}],null,null,0,false,Date,false,true&v=1&mt=%s',
   strCmdDeleteLiveLight = "http://%s/mail/InboxLight.aspx?FolderID=%s&",
   strCmdDeletePostLiveLight = "__VIEWSTATE=&mt=%s&MoveMessageSelector=%s&ToolbarActionItem=MoveMessageSelector&", -- SelectedMessages=%s",
   strCmdMsgView = "http://%s/cgi-bin/getmsg?msg=%s&imgsafe=y&curmbox=%s&a=%s",
@@ -236,14 +249,14 @@ local globals = {
   strCmdLogoutLive = "http://%s/mail/logout.aspx",
   strCmdFolders = "http://%s/cgi-bin/folders?&curmbox=F000000001&a=%s",
   strCmdFoldersLiveLight = "http://%s/mail/ManageFoldersLight.aspx?n=%s",
-  strCmdMsgUnreadLive = "http://%s/mail/mail.fpp?cnmn=Microsoft.Msn.Hotmail.MailBox.MarkMessages&ptid=0&a=", 
-  strCmdMsgUnreadLivePost = "cn=Microsoft.Msn.Hotmail.MailBox&mn=MarkMessages&d=false,[%s]",
-  strCmdEmptyTrashLive = "http://%s/mail/mail.fpp?cnmn=Microsoft.Msn.Hotmail.MailBox.EmptyFolder&ptid=0&a=&au=%s", 
-  strCmdEmptyTrashLivePost = "cn=Microsoft.Msn.Hotmail.MailBox&mn=EmptyFolder&d=%s,1&v=1&mt=%s",
+  strCmdMsgUnreadLive = "http://%s/mail/mail.fpp?cnmn=Microsoft.Msn.Hotmail.Ui.Fpp.MailBox.MarkMessages&ptid=0&a=%s&au=%s", 
+  strCmdMsgUnreadLivePost = "cn=Microsoft.Msn.Hotmail.Ui.Fpp.MailBox&mn=MarkMessages&d=false,[%s]",
+  strCmdEmptyTrashLive = "http://%s/mail/mail.fpp?cnmn=Microsoft.Msn.Hotmail.Ui.Fpp.MailBox.EmptyFolder&ptid=0&a=&au=%s", 
+  strCmdEmptyTrashLivePost = "cn=Microsoft.Msn.Hotmail.Ui.Fpp.MailBox&mn=EmptyFolder&d=%s,1&v=1&mt=%s",
   strCmdEmptyTrashLiveLight = "http://%s/mail/InboxLight.aspx?EmptyFolder=True&FolderID=%s&", 
   strCmdEmptyTrashLiveLightPost = "__VIEWSTATE=&mt=%s&query=&MoveMessageSelector=&ToolbarActionItem=&InfoPaneActionItem=EmptyFolderConfirmYes",
-  strCmdMsgReadLive = "http://%s/mail/mail.fpp?cnmn=Microsoft.Msn.Hotmail.MailBox.MarkMessages&ptid=0&a=&au=%s", 
-  strCmdMsgReadLivePost = "cn=Microsoft.Msn.Hotmail.MailBox&mn=MarkMessages&d=true,[%s]&v=1&mt=%s",
+  strCmdMsgReadLive = "http://%s/mail/mail.fpp?cnmn=Microsoft.Msn.Hotmail.Ui.Fpp.MailBox.MarkMessages&ptid=0&a=&au=%s", 
+  strCmdMsgReadLivePost = "cn=Microsoft.Msn.Hotmail.Ui.Fpp.MailBox&mn=MarkMessages&d=true,[%s]&v=1&mt=%s",
   strCmdMsgReadLiveLight = "http://%s/mail/ReadMessageLight.aspx?AllowUnsafe=True&Aux=&FolderID=%s&InboxSortAscending=False&InboxSortBy=Date&ReadMessageId=%s",
 }
 
@@ -274,6 +287,7 @@ internalState = {
   statLimit = nil,
   strUserId = "",
   strMT = "",
+  bKeepMsgStatus = false,
 }
 
 -- ************************************************************************** --
@@ -338,24 +352,28 @@ function hash()
 	 internalState.strPassword -- this asserts strPassword ~= nil
 end
 
-function getPage(browser, url)
+function getPage(browser, url, post, name)
   local try = 0
   while (try < 3) do
-    local body, err = browser:get_uri(url)
+    try = try + 1
+    local body, err = fetchPage(browser, url, post, name)
 
     if (body == nil) then
       log.raw("Tried to load: " .. url .. " and got error: " .. err)
-    elseif (string.find(body, "We are experiencing higher than normal volume") == nil and 
-        string.find(body, "<[Hh][Tt][Mm][Ll]") ~= nil and
-        string.find(body, "MSN Hotmail %- ERROR") == nil) then
-      return body, err
-    end
-    try = try + 1
-    local newurl = string.match(body, 'Object moved to <a href="([^"]+)"')
-    if (newurl ~= nil) then
-      return getPage(browser, newurl)
-    end
-    if (body ~= nil) then
+      log.error_print("Tried to load: " .. url .. " and got error: " .. err)
+      return nil, err
+    else
+      if (string.find(body, "We are experiencing higher than normal volume") == nil and 
+          string.find(body, "<[Hh][Tt][Mm][Ll]") ~= nil and
+          string.find(body, "MSN Hotmail %- ERROR") == nil) then
+        return body, err
+      end
+      -- This is a little bizarre -- It seems the condition should not be here.
+      --
+      local newurl = string.match(body, 'Object moved to <a href="([^"]+)"')
+      if (newurl ~= nil) then
+        return getPage(browser, newurl, nil, name)
+      end
       log.raw("Attempt to load: " .. url .. " failed in attempt: " .. try)
     end
   end
@@ -363,6 +381,15 @@ function getPage(browser, url)
   return nil, nil
 end
 
+function fetchPage(browser, url, post, name)
+  log.dbg("Fetching Page: " .. name .. " - " .. url)
+  if (post == nil) then
+    return browser:get_uri(url)
+  else
+    return browser:post_uri(url, post)
+  end
+end
+
 -- Issue the command to login to Hotmail
 --
 function loginHotmail()
@@ -376,7 +403,8 @@ function loginHotmail()
 
   -- Create a browser to do the dirty work
   --
-  internalState.browser = browser.new("Mozilla/4.0 (compatible; MSIE 7.0; Windows NT 5.1; YPC 3.0.1; .NET CLR 1.1.4322; .NET CLR 2.0.50727")
+  --internalState.browser = browser.new("Mozilla/4.0 (compatible; MSIE 7.0; Windows NT 5.1; YPC 3.0.1; .NET CLR 1.1.4322; .NET CLR 2.0.50727")
+  internalState.browser = browser.new("Mozilla/5.0 (X11; U; Linux i686; en-US; rv:1.8.1.12) Gecko/20080207 Ubuntu/7.10 (gutsy) Firefox/2.0.0.12")
 
   -- Define some local variables
   --
@@ -399,7 +427,7 @@ function loginHotmail()
 
   -- Retrieve the login page.
   --
-  local body, err = getPage(browser, url)
+  local body, err = getPage(browser, url, nil, "Live Mail Login Page")
 
   -- No connection
   --
@@ -453,7 +481,7 @@ function loginHotmail()
     end
   end
   if (postdata ~= nil) then
-    body, err = browser:post_uri(url, postdata)
+    body, err = getPage(browser, url, postdata, "Login Form Page")
   end
  
   -- We should be logged in now!  Unfortunately, we aren't done.  Hotmail returns a page
@@ -475,7 +503,7 @@ function loginHotmail()
     log.raw("Login failed: Sent login info to: " .. (url or "none") .. " and got something we weren't expecting(2):\n" .. body);
     return POPSERVER_ERR_NETWORK
   end
-  body, err = getPage(browser, url)
+  body, err = getPage(browser, url, nil, "Hotmail Today")
 
   -- Shouldn't happen but you never know
   --
@@ -489,7 +517,7 @@ function loginHotmail()
    local str = string.match(body, globals.strClassicCheckPattern)
    if str ~= nil then
      log.dbg("Hotmail: Detected Classic version.") 
-     body, err = browser:get_uri("http://www.hotmail.com")
+     body, err = getPage(browser, "http://www.hotmail.com", nil, "hotmail homepage")
    end 
 
   -- Check to see if we are using the new interface and are redirecting.
@@ -498,11 +526,11 @@ function loginHotmail()
   if string.match(body, globals.strLiveCheckPattern) or string.match(body, globals.strLiveCheckPattern2) then
     log.dbg("Hotmail: Detected LIVE version.") 
     str = string.format(globals.strCmdBrowserIgnoreLive, browser:wherearewe())
-    body, err = browser:get_uri(str)
+    body, err = getPage(browser, str, nil, "browser check")
     str = string.match(body, globals.strLiveMainPagePattern)
     if str ~= nil then
       str = string.format(globals.strCmdBaseLive, browser:wherearewe()) .. str
-      body, err = browser:get_uri(str)
+      body, err = getPage(browser, str, nil, "Main Page?")
     else
       str = string.match(body, globals.strLiveLightPagePattern)
       if (str ~= nil) then
@@ -523,20 +551,31 @@ function loginHotmail()
     local oldbody = body
     url = string.match(body, globals.strLoginDoneReloadToReloadPage)
     if url ~= nil then
-      body, err = browser:get_uri(url)
+      body, err = getPage(browser, url, nil, "Non-Live Login Success and Redirect")
       if body == nil then
        	-- cdmackie: switch back to old body because we need to first process img in strLoginDoneReloadToHMHome4
        	body = oldbody
       end
     end
+
+    -- Paco
+    body = cleanupLoginBody(body)
+
     url = string.match(body, globals.strLoginDoneReloadToHMHome1)
     if url == nil then
       url = string.match(body, globals.strLoginDoneReloadToHMHome2)
       if url == nil then
         -- Change suggested by 930     
         local authimgurl = string.match(body, globals.strLoginDoneReloadToHMHome4)
+          -- Paco
+          --
+          if authimgurl == nil then
+            authimgurl = string.match(body, globals.strLoginDoneReloadToHMHome5)
+          end
+          log.raw("Image url: " .. authimgurl)
+
           if authimgurl ~= nil then
-            browser:get_uri(authimgurl)
+            getPage(browser, authimgurl, nil, "Authentication Image Url - NonLive")
           end
         url = string.match(body, globals.strLoginDoneReloadToHMHome3)
         if url == nil then
@@ -547,7 +586,14 @@ function loginHotmail()
         -- End change
       end
     end
-    body, err = browser:get_uri(url)
+    body, err = getPage(browser, url, nil, "NonLive - Login Redirect")
+
+    -- Paco
+    if body == nil then
+      log.error_print(globals.strLoginFailed)
+      log.raw("Login failed: Sent login info to: " .. (url or "none") .. " and got an error:\n" .. err);
+      return POPSERVER_ERR_NETWORK
+    end
   end
 
   -- Extract the crumb - This is needed for deletion of items
@@ -627,7 +673,7 @@ function loginHotmail()
   if (internalState.strMBox == nil and internalState.bLiveGUI == false) then
     local url = string.format(globals.strCmdFolders, internalState.strMailServer, 
       internalState.strCrumb)
-    body, err = browser:get_uri(url)
+    body, err = getPage(browser, url, nil, "Manage Folders Page")
     str = string.match(body, globals.strFolderPattern .. internalState.strMBoxName .. "</a>")
     if (str == nil and domain == "msn.com" and internalState.strMBoxName == "Inbox") then
       str = string.match(body, globals.strPatMSNInboxId)
@@ -651,28 +697,16 @@ function loginHotmail()
       internalState.strTrashId = str
       log.dbg("Hotmail - trash folder id: " .. str)
     else
-      str = string.match(body, globals.strFolderLiveLightTrash2Pattern) 
-      if str ~= nil then
-        internalState.strTrashId = str
-        log.dbg("Hotmail - trash folder id: " .. str)
-      else
         log.error_print("Unable to detect the folder id for the trash folder.  Deletion may fail.")
       end
-    end
 
     str = string.match(body, globals.strPatLiveJunkId) 
     if str ~= nil then
       internalState.strJunkId = str
       log.dbg("Hotmail - junk folder id: " .. str)
     else
-      str = string.match(body, globals.strFolderLiveLightJunk2Pattern) 
-      if str ~= nil then
-        internalState.strJunkId = str
-        log.dbg("Hotmail - junk folder id: " .. str)
-      else
         log.error_print("Unable to detect the folder id for the junk folder.  Deletion may fail.")
       end
-    end
 
     if (internalState.strMBoxName == "Inbox") then
       str = inboxId
@@ -694,7 +728,7 @@ function loginHotmail()
     local n = string.match(body, globals.strFolderLiveLightManageFoldersPattern)
     local url = string.format(globals.strCmdFoldersLiveLight, internalState.strMailServer, n)    
     
-    body, err = browser:get_uri(url)
+    body, err = getPage(browser, url, nil, "LiveLight - Manage Folders")
     
     -- cdmackie: we then extract the querystring and apend the InboxId with the N value
     local inboxQueryString = string.match(body, globals.strFolderLiveLightInboxPattern)
@@ -723,17 +757,29 @@ function loginHotmail()
       internalState.strTrashId = str
       log.dbg("Hotmail - trash folder id: " .. str)
     else
+      str = string.match(body, globals.strFolderLiveLightTrash2Pattern) 
+      if str ~= nil then
+        internalState.strTrashId = str
+        log.dbg("Hotmail - trash folder id: " .. str)
+      else
       log.error_print("Unable to detect the folder id for the trash folder.  Deletion may fail.")
     end
+    end
 
     str = string.match(body, globals.strFolderLiveLightJunkPattern) 
     if str ~= nil then
       internalState.strJunkId = str
       log.dbg("Hotmail - junk folder id: " .. str)
     else
+      str = string.match(body, globals.strFolderLiveLightJunk2Pattern) 
+      if str ~= nil then
+        internalState.strJunkId = str
+        log.dbg("Hotmail - junk folder id: " .. str)
+      else
       log.error_print("Unable to detect the folder id for the junk folder.  Deletion may fail.")
     end
   end
+  end
 
   -- Note that we have logged in successfully
   --
@@ -750,6 +796,28 @@ function loginHotmail()
   return POPSERVER_ERR_OK
 end
 
+function cleanupLoginBody(body)
+  log.raw("Cleaning up login body: " .. body)
+  body = string.gsub(body, "&#58;", ":")
+  body = string.gsub(body, "&#61;", "=")
+  body = string.gsub(body, "&#39;", "'")
+  body = string.gsub(body, "&#92;", "\\")
+  body = string.gsub(body, "&#47;", "/")
+  body = string.gsub(body, "&#63;", "?")
+  body = string.gsub(body, "&#38;", "&")
+  body = string.gsub(body, "&#42;", "*")
+  body = string.gsub(body, "&#33;", "!")
+  body = string.gsub(body, "&#36;", "$")
+  body = string.gsub(body, "\\x3a", ":")
+  body = string.gsub(body, "\\x2f", "/")
+  body = string.gsub(body, "\\x3f", "?")
+  body = string.gsub(body, "\\x3d", "=")
+  body = string.gsub(body, "\\x26", "&")
+  log.raw("Body cleaned: " .. body)
+
+  return body
+end
+
 function getFolderId(inboxId) 
   local cmdUrl = string.format(globals.strCmdMsgListLive, internalState.strMailServer,
     internalState.strCrumb, internalState.strUserId)
@@ -848,7 +916,7 @@ function downloadMsg(pstate, msg, nLines, data)
     -- as we've reached end of buffer..and hotmail doesn't always send "</pre>"
     cbInfo.bEndReached = true
     cbInfo.nLinesReceived = -1;
-    -- apply same fixup from cleanupbody to remove dead tags
+    -- apply same fixup from cleanupbody to remove dead tags -- I have doubts that this ever does anything.
     if (string.len(body) > 6) then
       local idx = string.find(string.sub(body, -6), "([&<])")
       if (idx ~= nil) then
@@ -859,6 +927,7 @@ function downloadMsg(pstate, msg, nLines, data)
       end
     end
     -- make sure we end in a crlf
+	body = string.gsub(body, "</\r\n", "\r\n") 
     if (string.sub(body, -2, -1) ~= "\r\n") then
       body = body .. "\r\n"
     end
@@ -871,11 +940,15 @@ function downloadMsg(pstate, msg, nLines, data)
     popserver_callback(body, data)
   elseif (cbInfo.bEndReached == false and cbInfo.nLinesRequested == -2) then
       popserver_callback("\r\n\0", data)
+  elseif (cbInfo.nLinesRequested ~= -2) then
+      popserver_callback("\r\n\0", data)
   end
 
   -- Mark the message as read
   --
-  if internalState.bMarkMsgAsUnread == false and internalState.bLiveGUI == false then
+  if (internalState.bKeepMsgStatus == true) then
+    -- no op
+  elseif internalState.bMarkMsgAsUnread == false and internalState.bLiveGUI == false then
     log.raw("Message: " .. cbInfo.cb_uidl .. ", Marking message as being done.")
     browser:get_head(markReadUrl)
   elseif internalState.bMarkMsgAsUnread == false and internalState.bLiveGUI and internalState.bLiveLightGUI == false then
@@ -889,7 +962,7 @@ function downloadMsg(pstate, msg, nLines, data)
     browser:get_head(url)
   elseif internalState.bMarkMsgAsUnread == true and internalState.bLiveGUI == true then
     log.raw("Message: " .. cbInfo.cb_uidl .. ", Marking message as unread.")
-    url = string.format(globals.strCmdMsgUnreadLive, internalState.strMailServer)
+    url = string.format(globals.strCmdMsgUnreadLive, internalState.strMailServer, internalState.strCrumb, internalState.strUserId)
     local post = string.format(globals.strCmdMsgUnreadLivePost, uidl)
     browser:post_uri(url, post)
   end
@@ -952,9 +1025,11 @@ function downloadMsg_cb(cbInfo, data)
       --
       if cbInfo.strHack:check_stop(cbInfo.nLinesRequested) then
         cbInfo.nLinesReceived = -1;
-        if (string.sub(body, -2, -1) ~= "\r\n") then
-          body = body .. "\r\n"
-        end
+        -- This is now handled in the parent function
+        --
+--        if (string.sub(body, -2, -1) ~= "\r\n") then
+--          body = body .. "\r\n"
+--        end
       else
         cbInfo.nLinesReceived = cbInfo.nLinesRequested - 
           cbInfo.strHack:current_lines()
@@ -1059,6 +1134,7 @@ function cleanupBody(body, cbInfo)
   body = string.gsub(body, "&#09;", "\t")
   body = string.gsub(body, "&#10;", "\n")
   body = string.gsub(body, "&#13;", "\r")
+  body = string.gsub(body, "&#27;", "\27")
   body = string.gsub(body, "&#32;", " ")
   body = string.gsub(body, "&#33;", "!")
   body = string.gsub(body, "&#35;", "#")
@@ -1120,6 +1196,10 @@ function cleanupBody(body, cbInfo)
 
   -- cdmackie: POP protocol: lines starting with a dot must be escaped dotdot
   body = string.gsub(body, "\r\n%.", "\r\n%.%.")
+  
+  -- Experimental -- For non-ascii users
+  --
+  body = string.gsub(body, "&#(%d-);", function(c) return string.byte(c) end)
 
   -- We've now at least seen one block, attempt to clean up the headers
   --
@@ -1191,6 +1271,17 @@ function user(pstate, username)
     internalState.statLimit = tonumber(val)
   end
 
+  -- If the flag keepmsgstatus=1 is set, then we won't touch the status of 
+  -- messages that we pull.
+  --
+  local val = (freepops.MODULE_ARGS or {}).keepmsgstatus or 0
+  if val == "1" then
+    log.dbg("Hotmail: All messages pulled will have its status left alone.")
+    internalState.bKeepMsgStatus = true
+  end
+
+
+
   -- Get the folder
   --
   local mbox = (freepops.MODULE_ARGS or {}).folder
@@ -1316,9 +1407,9 @@ function quit_update(pstate)
 
       -- Send out in a batch of 5
       --
-      if math.mod(dcnt, 5) == 0 then
+      if math.fmod(dcnt, 5) == 0 then
         log.dbg("Sending Delete URL: " .. cmdUrl .. "Post Data: " .. post .. "\n")
-        local body, err = browser:post_uri(cmdUrl, post)
+        local body, err = getPage(browser, cmdUrl, post, "Delete Messages - NonLive")
         if not body or err then
           log.error_print("Unable to delete messages.\n")
         end
@@ -1355,7 +1446,7 @@ function quit_update(pstate)
     post = string.format(globals.strCmdDeletePostLiveLight, internalState.strMT, 
       internalState.strTrashId) .. uidlsLight
     log.dbg("Sending Trash url: " .. cmdUrl .. " - " .. post)
-    local body, err = browser:post_uri(cmdUrl, post)
+    local body, err = getPage(browser, cmdUrl, post, "Delete Messages - LiveLight")
   elseif dcnt > 0 and internalState.bLiveGUI then
     cmdUrl = string.format(globals.strCmdDeleteLive, internalState.strMailServer, internalState.strCrumb, internalState.strUserId)
     uidls = string.gsub(uidls, ",", '","')
@@ -1363,11 +1454,11 @@ function quit_update(pstate)
     post = string.format(globals.strCmdDeletePostLive, internalState.strMBox, 
       internalState.strTrashId, uidls, internalState.strMT)
     log.dbg("Sending Trash url: " .. cmdUrl .. " - " .. post)
-    local body, err = browser:post_uri(cmdUrl, post)
+    local body, err = getPage(browser, cmdUrl, post, "Delete Messages - Live")
     if (body == nil) then -- M7 Only - DELETE SOON!
       post = string.format(globals.strCmdDeletePostLiveOld, internalState.strMBox, 
         internalState.strTrashId, uidls)
-      local body, err = browser:post_uri(cmdUrl, post)
+      local body, err = getPage(browser, cmdUrl, post, "Delete Messages - Live")
     end
   end
 
@@ -1377,7 +1468,7 @@ function quit_update(pstate)
     if internalState.strCrumb ~= '' then
       cmdUrl = string.format(globals.strCmdEmptyTrash, internalState.strMailServer,internalState.strCrumb)
       log.dbg("Sending Empty Trash URL: " .. cmdUrl .."\n")
-      local body, err = getPage(browser, cmdUrl)
+      local body, err = getPage(browser, cmdUrl, nil, "NonLive - Empty Trash")
       if not body or err then
         log.error_print("Error when trying to empty the trash with url: ".. cmdUrl .."\n")
       end
@@ -1388,7 +1479,7 @@ function quit_update(pstate)
     cmdUrl = string.format(globals.strCmdEmptyTrashLiveLight, internalState.strMailServer, internalState.strTrashId)
     local post = string.format(globals.strCmdEmptyTrashLiveLightPost, internalState.strMT)
     log.dbg("Sending Empty Trash URL: " .. cmdUrl .."\n")
-    local body, err = browser:post_uri(cmdUrl, post)
+    local body, err = getPage(browser, cmdUrl, post, "LiveLight - Empty Trash")
     if not body or err then
       log.error_print("Error when trying to empty the trash with url: ".. cmdUrl .."\n")
     end
@@ -1396,7 +1487,7 @@ function quit_update(pstate)
     cmdUrl = string.format(globals.strCmdEmptyTrashLive, internalState.strMailServer, internalState.strUserId)
     local post = string.format(globals.strCmdEmptyTrashLivePost, internalState.strTrashId, internalState.strMT)
     log.dbg("Sending Empty Trash URL: " .. cmdUrl .."\n")
-    local body, err = browser:post_uri(cmdUrl, post)
+    local body, err = getPage(browser, cmdUrl, post, "Live - Empty Trash")
     if not body or err then
       log.error_print("Error when trying to empty the trash with url: ".. cmdUrl .."\n")
     end
@@ -1408,7 +1499,7 @@ function quit_update(pstate)
     cmdUrl = string.format(globals.strCmdEmptyTrashLiveLight, internalState.strMailServer, internalState.strJunkId)
     local post = string.format(globals.strCmdEmptyTrashLiveLightPost, internalState.strMT)
     log.dbg("Sending Empty Junk URL: " .. cmdUrl .."\n")
-    local body, err = browser:post_uri(cmdUrl, post)
+    local body, err = getPage(browser, cmdUrl, post, "LiveLight - Empty Junk")
     if not body or err then
       log.error_print("Error when trying to empty the junk folder with url: ".. cmdUrl .."\n")
     end
@@ -1416,7 +1507,7 @@ function quit_update(pstate)
     cmdUrl = string.format(globals.strCmdEmptyTrashLive, internalState.strMailServer, internalState.strUserId)
     local post = string.format(globals.strCmdEmptyTrashLivePost, internalState.strJunkId)
     log.dbg("Sending Empty Junk URL: " .. cmdUrl .."\n")
-    local body, err = browser:post_uri(cmdUrl, post)
+    local body, err = getPage(browser, cmdUrl, post, "Live - Empty Junk")
     if not body or err then
       log.error_print("Error when trying to empty the junk folder with url: ".. cmdUrl .."\n")
     end
@@ -1458,11 +1549,11 @@ function logout()
     cmdUrl = string.format(globals.strCmdLogout, internalState.strMailServer)
   end
   log.dbg("Sending Logout URL: " .. cmdUrl .. "\n")
-  local body, err = getPage(browser, cmdUrl)
+  local body, err = getPage(browser, cmdUrl, nil, "Logout Page")
   if (internalState.bLiveGUI) then
     cmdUrl = string.match(body, '<meta http-equiv="refresh" content="%d+;url=([^"]+)" />')
     if (cmdUrl ~= nil) then
-      body, err = getPage(browser, cmdUrl)
+      body, err = getPage(browser, cmdUrl, nil, "Redirected Logout Page")
     end
   end
 end
@@ -1505,16 +1596,23 @@ function LiveStat(pstate)
 
   -- Let's make sure the session is still valid
   --
-  local strSessExpr = string.match(body, globals.strRetLoginSessionExpiredLive)
-  if strSessExpr ~= nil then
+  local sessionExpired = (body == nil) or string.match(body, globals.strRetLoginSessionExpiredLive) == nil
+  if sessionExpired then
     -- Invalidate the session
     --
     internalState.bLoginDone = nil
     session.remove(hash())
-    log.raw("Session Expired - Last page loaded: " .. cmdUrl .. ", Body: " .. body)
+    local strLog = "Session Expired - Last page loaded: " .. cmdUrl .. ", Body"
+    if (body == nil) then
+      strLog = strLog .. " was 'nil'"
+    else
+      strLog = strLog .. ": " .. body
+    end
+    log.raw(strLog)
 
     -- Try Logging back in
     --
+    logout() 
     local status = loginHotmail()
     if status ~= POPSERVER_ERR_OK then
       return POPSERVER_ERR_NETWORK
@@ -1726,6 +1824,13 @@ function stat(pstate)
     -- Figure out if there are more pages with messages
     --
     nextPageUrl = string.match(body, globals.strMsgListNextPagePatLiveLight)
+    -- cdmackie: change in hotmail nextpage link (kept old one incase still used)
+    if nextPageUrl == nil then
+	    nextPageUrl = string.match(body, globals.strMsgListNextPagePatLiveLight2)
+    end
+    if (nextPageUrl ~= nil) then
+       log.dbg("Found another page of messages: " .. nextPageUrl)
+    end
 
     -- Tokenize out the message ID and size for each item in the list
     --    
@@ -1825,7 +1930,7 @@ function stat(pstate)
 
     -- Get the page and check to see if we got results
     --
-    local body, err = getPage(browser, cmdUrl)
+    local body, err = getPage(browser, cmdUrl, nil, "STAT Page - LiveLight and NonLive")
     if body == nil then
       return body, err
     end
@@ -1840,7 +1945,8 @@ function stat(pstate)
     -- Is the session expired
     --
     local strSessExpr = string.match(body, globals.strRetLoginSessionExpired)
-    if strSessExpr ~= nil then
+    local strSessExprLight = string.match(body, globals.strRetLoginSessionExpiredLiveLight)
+    if strSessExpr ~= nil or strSessExprLight == nil then
       -- Invalidate the session
       --
       internalState.bLoginDone = nil
@@ -1849,6 +1955,7 @@ function stat(pstate)
 
       -- Try Logging back in
       --
+      logout() 
       local status = loginHotmail()
       if status ~= POPSERVER_ERR_OK then
         return nil, "Session expired.  Unable to recover"
@@ -1871,7 +1978,7 @@ function stat(pstate)
 
       -- Retry to load the page
       --
-      return getPage(browser, cmdUrl)
+      return getPage(browser, cmdUrl, nil, "STAT Page - LiveLight and NonLive")
     end
 
     -- Get the total number of messages
