@@ -17,7 +17,7 @@
 -- ************************************************************************** --
 --  FreePOPs @libero.it, @inwind.it, @blu.it, @iol.it webmail interface
 --  
---  $Id: libero.lua,v 1.58 2007/11/10 23:04:49 gareuselesinge Exp $
+--  $Id: libero.lua,v 1.60 2008/05/29 13:36:29 gareuselesinge Exp $
 --  
 --  Released under the GNU/GPL license
 --  Written by Enrico Tassi <gareuselesinge@users.sourceforge.net>
@@ -27,7 +27,7 @@
 -- fill them in the right way
 
 -- single string, all required
-PLUGIN_VERSION = "0.2.12"
+PLUGIN_VERSION = "0.2.13"
 PLUGIN_NAME = "Libero.IT"
 PLUGIN_REQUIRE_VERSION = "0.2.0"
 PLUGIN_LICENSE = "GNU/GPL"
@@ -219,7 +219,7 @@ function libero_login()
 
 	-- build the uri
 	local password = internal_state.password
-	local popnumber = math.mod(os.time(),15) + 1  -- == random(1..15)
+	local popnumber = math.fmod(os.time(),15) + 1  -- == random(1..15)
 	local domain = internal_state.domain
 	local site = libero_domain[domain].website
 	local choice = libero_domain[domain].choice
@@ -227,7 +227,7 @@ function libero_login()
 	if internal_state.domain ~= "libero.it" then
 		user = user .. "@" .. domain
 	end
-	local x,y = math.mod(os.time(),16),math.mod(os.time()*2,16)
+	local x,y = math.fmod(os.time(),16),math.fmod(os.time()*2,16)
 	local uri = string.format(libero_string.login_url,popnumber,site)
         log.dbg("Using webserver " .. uri);
 	local post= string.format(libero_string.login_post,
