@@ -7,7 +7,7 @@
 
 -- Globals
 --
-PLUGIN_VERSION = "0.1.07"
+PLUGIN_VERSION = "0.1.07b"
 PLUGIN_NAME = "mail.com"
 PLUGIN_REQUIRE_VERSION = "0.2.0"
 PLUGIN_LICENSE = "GNU/GPL"
@@ -70,7 +70,7 @@ PLUGIN_DOMAINS = {"@mail.com","@email.com","@iname.com","@cheerful.com","@consul
 "@webcity.ca","@webmail.lu","@welcomm.ac","@wenxuecity.net","@westham-mail.com","@wimbledon-mail.com",
 "@windrivers.net","@wolves-mail.com","@wongfaye.com","@worldmail.ac","@worldweb.ac","@isleuthmail.com",
 "@x-lab.cc","@xy.com.tw","@yankeeman.com","@yyhmail.com", "@verizonmail.com", "@lycos.com", "@cyberdude.com",
-"@mail.org", "@italymail.com", "@mexico.com", "@india.com", "@u2club.com" }
+"@mail.org", "@italymail.com", "@mexico.com", "@india.com", "@u2club.com", "@royal.net" }
 PLUGIN_PARAMETERS = {
 	{name = "folder", description = {
 		en = [[
@@ -315,7 +315,7 @@ function login()
   if (internalState.strLoginPage ~= nil) then
     url = internalState.strLoginPage
   elseif (domain == "email.com" or domain == "mail.com" or domain == "iname.com" or domain == "mail.org" or 
-        internalState.bUseMailComLoginPage) then
+         domain == "royal.net" or internalState.bUseMailComLoginPage) then
     url = string.format(globals.strLoginPage, "www2", "mail.com")
   elseif (domain == "usa.com" or domain == "mexico.com") then
     url = string.format(globals.strLoginPage, "mail", domain)
@@ -533,6 +533,7 @@ function cleanupHeaders(headers)
   headers = string.gsub(headers, "&gt;", ">")
   headers = string.gsub(headers, "&lt;", "<")
   headers = string.gsub(headers, "&nbsp;", " ")
+  headers = string.gsub(headers, "[Cc][Oo][Nn][Tt][Ee][Nn][Tt]%-[Tt][Rr][Aa][Nn][Ss][Ff][Ee][Rr]%-[Ee][Nn][Cc][Oo][Dd][Ii][Nn][Gg]: .-\n", "", 1);
   headers = string.gsub(headers, "From:", "From: ")
   headers = string.gsub(headers, "To:", "To: ")
   headers = string.gsub(headers, "CC:", "CC: ")
@@ -553,6 +554,7 @@ function cleanupHeaders(headers)
   headers = string.gsub(headers, "Previous | Next", "")  
   headers = string.gsub(headers, "\n\n", "\n")
 
+
   -- Add some headers
   --
   headers = string.gsub(headers, "%s+$", "\n")
