@@ -7,7 +7,7 @@
 
 -- Globals
 --
-PLUGIN_VERSION = "0.0.8f"
+PLUGIN_VERSION = "0.0.8g"
 PLUGIN_NAME = "Orange (ex Wanadoo)"
 PLUGIN_REQUIRE_VERSION = "0.0.99"
 PLUGIN_LICENSE = "GNU/GPL"
@@ -20,7 +20,7 @@ PLUGIN_AUTHORS_CONTACTS = {"themarco (at) fsmail (.) net","evaarties (at) xs4all
 -- if more domains & countries are added, the code in  
 -- function user(pstate, username) needs to be updated accordingly
 --
-PLUGIN_DOMAINS = {"@fsmail.net","@wanadoo.nl","@orange.nl","@orange.co.uk","@bedrijfsnaam.nl"}
+PLUGIN_DOMAINS = {"@fsmail.net","@wanadoo.nl","@orange.nl","@bedrijfsnaam.nl"}
 PLUGIN_PARAMETERS = {
 	{name="folder", description={
 		it=[[La cartella da ispezionare. Quella di default &egrave; inbox, gli altri valori possibili sono: junk, sent, trash, draft o cartella definita dall'utente.]],
@@ -460,7 +460,7 @@ function user(pstate, username)
   
   -- copied from the javascript code on the orange webpage: assign server number randomly
   -- (os.time()%3)+1 -- ... 1 to 3
-  internalState.strBaseUrl= string.format(globals.strBaseUrl, leading, math.mod(os.time(),3)+1 , country, language)
+  internalState.strBaseUrl= string.format(globals.strBaseUrl, leading, math.fmod(os.time(),3)+1 , country, language)
   
   log.dbg ("Domain: " .. domain .. " Initial login uri: " .. internalState.strBaseUrl .. "\n")
 
@@ -1154,7 +1154,7 @@ function Private.base64_io_slave(cb)
 			table.insert(todo_table,base64.encode(chunk).."\r\n")
 			buffer = string.sub(buffer,Private.base64wrap + 1,-1)
 		end
-		if #todo_table > 0 then
+		if table.getn(todo_table) > 0 then
 			cb(table.concat(todo_table))
 		end
 
@@ -1256,7 +1256,7 @@ function Private.quoted_printable_io_slave(cb)
 			buffer = string.sub(buffer,len + 1,-1)
 			wrap,forced,len = Private.qpr_eval_expansion(buffer)
 		end
-		if #todo_table > 0 then
+		if table.getn(todo_table) > 0 then
 			cb(table.concat(todo_table))
 		end
 		if len == 0 then
@@ -1640,9 +1640,9 @@ function omimer.pipe_msg(headers,body,body_html,base_uri,attachments,browser,sen
 	--body = body or html2txtmail(body_html,base_uri)
 	local isAlt, isInline, isAttached, boundary, cType
 	--initialize randomize_boundary
-	math.randomseed(math.mod(os.time(),37))
+	math.randomseed(math.fmod(os.time(),37))
 	local j = math.random(67)
-	math.randomseed((math.mod((os.time()/j),73)+1)*j)
+	math.randomseed((math.fmod((os.time()/j),73)+1)*j)
 
 	isAttached = table.getn(attachments) > table.getn(inlineids)
 	isAlt = body and body_html
