@@ -1,5 +1,5 @@
 /******************************************************************************
- * $Id: luabox.c,v 1.10 2007/10/22 21:43:48 gareuselesinge Exp $
+ * $Id: luabox.c,v 1.12 2008/06/05 14:12:05 gareuselesinge Exp $
  * This file is part of FreePOPs (http://www.freepops.org)					*
  * This file is distributed under the terms of GNU GPL license.			   *
  ******************************************************************************/
@@ -13,6 +13,8 @@
  *		Enrico Tassi <gareuselesinge@users.sourceforge.net>
  ******************************************************************************/
 
+#include <strings.h>
+
 #include "lua.h"
 #include "lualib.h"
 #include "lauxlib.h"
@@ -28,7 +30,7 @@
 #include "session_lua.h"
 #include "lua-curl.h"
 #include "getdate_lua.h"
-#include "psock_lua.h"
+#include "luasocket.h"
 #include "base64_lua.h"
 #include "regularexp_lua.h"
 #include "lxplib.h"
@@ -40,23 +42,27 @@
 #include "log.h"
 #define LOG_ZONE "LUABOX"
 
-struct entry_t { const char* name; int (*open)(lua_State*); }; 
+struct entry_t { 
+	const char* name_to_preload; 
+	const char* name_to_require; 
+	int (*open)(lua_State*); 
+}; 
 static struct entry_t libs[LUABOX_LAST] = {
-		{"pop3server",luaopen_pop3server},
-		{"mlex",luaopen_mlex},
-		{"stringhack",luaopen_stringhack},
-		{"session",luaopen_session},
-		{"curl",luaopen_curl},
-		{"psock",luaopen_psock},
-		{"base64",luaopen_base64},
-		{"getdate",luaopen_getdate},
-		{"regularexp",luaopen_regularexp},
-		{"lxp",luaopen_lxp},
-		{"log",luaopen_log},
-		{"crypto",luaopen_crypto},
-		{"lfs",luaopen_lfs},
-		{"dpipe",luaopen_dpipe},
-		{"stats",luaopen_stats},
+	{"pop3server","pop3server",luaopen_pop3server},
+	{"mlex","mlex",luaopen_mlex},
+	{"stringhack","stringhack",luaopen_stringhack},
+	{"session","session",luaopen_session},
+	{"curl","curl",luaopen_curl},
+	{"socket.core","socket",luaopen_socket_core},
+	{"base64","base64",luaopen_base64},
+	{"getdate","getdate",luaopen_getdate},
+	{"regularexp","regularexp",luaopen_regularexp},
+	{"lxp","lxp",luaopen_lxp},
+	{"log","log",luaopen_log},
+	{"crypto","crypto",luaopen_crypto},
+	{"lfs","lfs",luaopen_lfs},
+	{"dpipe","dpipe",luaopen_dpipe},
+	{"stats","stats",luaopen_stats},
 };
 
 lua_State* luabox_genbox(unsigned long intial_stuff){
@@ -72,7 +78,7 @@ lua_State* luabox_genbox(unsigned long intial_stuff){
 	lua_getfield(box,-1,"preload");
 	for ( i = 0 ; i < LUABOX_LAST ; i++) {
 		lua_pushcfunction(box,libs[i].open);
-		lua_setfield(box,-2,libs[i].name);
+		lua_setfield(box,-2,libs[i].name_to_preload);
 	}
 	luay_emptystack(box);		
 	luabox_addtobox(box,intial_stuff);
@@ -84,7 +90,7 @@ void luabox_addtobox(lua_State* box,unsigned long stuff){
 	for ( i = 0 ; i < LUABOX_LAST ; i++) {
 		int j = 1<<i;
 		if (j & stuff) {
-			luay_call(box,"s|","require", libs[i].name);
+			luay_call(box,"s|","require", libs[i].name_to_require);
 			luay_emptystack(box);		
 		}
 	}
