@@ -1,5 +1,5 @@
 /******************************************************************************
- * $Id: main.cxx,v 1.3 2007/11/11 16:14:26 gareuselesinge Exp $
+ * $Id: main.cxx,v 1.5 2008/06/11 19:23:25 gareuselesinge Exp $
  * This file is part of FreePOPs (http://www.freepops.org)                    *
  * This file is distributed under the terms of GNU GPL license.               *
  ******************************************************************************/
@@ -15,18 +15,24 @@
 
 #include <stdlib.h>
 #include <lua.hpp>
+#include <libintl.h>
+#include <locale.h>
 
 #include "updater.h"
 #include "linker.h"
 
 static int updater_run(lua_State* l){
+	setlocale(LC_MESSAGES, "");
+	#ifdef WIN32
+	  bindtextdomain("updater_fltk", "LANG");
+	#else
+	  bindtextdomain("updater_fltk", LOCALEDIR);
+	#endif
+	textdomain("updater_fltk");
+	
 	Fl_Double_Window* win = make_main_window();
 	updater_init(l);
-#ifdef WIN32
 	char* argv[] = {"freepops"};
-#else
-	const char* argv[] = {"freepops"};
-#endif
 	win->show(1, argv);
 	lua_pushnumber(l,Fl::run());
 	return 1;
